==> gammaray_2.3.0.orig.tar.gz: gammaray-2.3.0/core/toolpluginmodel.h <==
/*
  This file is part of GammaRay, the Qt application inspection and
  manipulation tool.

  Copyright (C) 2012-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
  Author: Kevin Funk <kevin.funk@kdab.com>

  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
  accordance with GammaRay Commercial License Agreement provided with the Software.

  Contact info@kdab.com if any conditions of this licensing are not clear to you.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef GAMMARAY_TOOLPLUGINMODEL_H
#define GAMMARAY_TOOLPLUGINMODEL_H

#include <QAbstractTableModel>
#include <QVector>

namespace GammaRay {

class ToolFactory;

/** Information about loaded plugins, for display in the about dialog. */
class ToolPluginModel : public QAbstractTableModel
{
    Q_OBJECT
public:
    explicit ToolPluginModel(const QVector<ToolFactory*> &plugins, QObject *parent = 0);
    ~ToolPluginModel();

    QVariant data(const QModelIndex& index, int role) const Q_DECL_OVERRIDE;
    int columnCount(const QModelIndex& parent) const Q_DECL_OVERRIDE;
    int rowCount(const QModelIndex& parent) const Q_DECL_OVERRIDE;
    QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const Q_DECL_OVERRIDE;

private:
    QVector<ToolFactory*> m_tools;
};
}

#endif // GAMMARAY_TOOLPLUGINMODEL_H

==> gammaray_2.11.0.orig.tar.gz: gammaray-2.11.0/core/toolpluginmodel.h <==
/*
  This file is part of GammaRay, the Qt application inspection and
  manipulation tool.

  Copyright (C) 2012-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
  Author: Kevin Funk <kevin.funk@kdab.com>

  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
  accordance with GammaRay Commercial License Agreement provided with the Software.

  Contact info@kdab.com if any conditions of this licensing are not clear to you.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef GAMMARAY_TOOLPLUGINMODEL_H
#define GAMMARAY_TOOLPLUGINMODEL_H

#include <QAbstractTableModel>
#include <QVector>

namespace GammaRay {
class ToolFactory;

/** Information about loaded plugins, for display in the about dialog. */
class ToolPluginModel : public QAbstractTableModel
{
    Q_OBJECT
public:
    explicit ToolPluginModel(const QVector<ToolFactory *> &plugins, QObject *parent = nullptr);
    ~ToolPluginModel() override;

    QVariant data(const QModelIndex &index, int role) const override;
    int columnCount(const QModelIndex &parent) const override;
    int rowCount(const QModelIndex &parent) const override;
    QVariant headerData(int section, Qt::Orientation orientation,
                        int role = Qt::DisplayRole) const override;

private:
    QVector<ToolFactory *> m_tools;
};
}

#endif // GAMMARAY_TOOLPLUGINMODEL_H
